Struct google_language1::AnalyzeSyntaxRequest [−][src]
pub struct AnalyzeSyntaxRequest {
pub encoding_type: Option<String>,
pub document: Option<Document>,
}The syntax analysis request message.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- analyze syntax documents (request)
Fields
encoding_type: Option<String>
The encoding type used by the API to calculate offsets.
document: Option<Document>
Input document.