Struct google_language1::AnalyzeSyntaxResponse [−][src]
pub struct AnalyzeSyntaxResponse {
pub tokens: Option<Vec<Token>>,
pub language: Option<String>,
pub sentences: Option<Vec<Sentence>>,
}The syntax analysis response message.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- analyze syntax documents (response)
Fields
tokens: Option<Vec<Token>>
Tokens, along with their syntactic information, in the input document.
language: Option<String>
The language of the text, which will be the same as the language specified in the request or, if not specified, the automatically-detected language. See Document.language field for more details.
sentences: Option<Vec<Sentence>>
Sentences in the input document.