Struct google_language1::ClassifyTextRequest [−][src]
The document classification request message.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- classify text documents (request)
Fields
document: Option<Document>
Input document.