Struct google_language1::ClassifyTextResponse [−][src]
pub struct ClassifyTextResponse {
pub categories: Option<Vec<ClassificationCategory>>,
}The document classification response message.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- classify text documents (response)
Fields
categories: Option<Vec<ClassificationCategory>>
Categories representing the input document.