Struct google_language1::Sentence [−][src]
Represents a sentence in the input document.
This type is not used in any activity, and only used as part of another schema.
Fields
text: Option<TextSpan>
The sentence text.
sentiment: Option<Sentiment>
For calls to AnalyzeSentiment or if AnnotateTextRequest.Features.extract_document_sentiment is set to true, this field will contain the sentiment for the sentence.